@@ -8,7 +8,7 @@ if fact('osfamily') == 'RedHat' and fact('selinux') == 'true'
   shell 'setenforce 0'
 end
 
-describe 'postgres::server', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+describe 'postgresql::server', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   it 'on an alternative pgdata location' do
     pp = <<-EOS
       #file { '/var/lib/pgsql': ensure => directory, } ->
