@@ -12,8 +12,10 @@ describe 'postgresql::client', :type => :class do
   describe 'with parameters' do
     let :params do
       {
+        :validcon_script_path  => '/opt/bin/my-validate-con.sh',
         :package_ensure => 'absent',
-        :package_name => 'mypackage',
+        :package_name   => 'mypackage',
+        :file_ensure    => 'file'
       }
     end
 
@@ -24,6 +26,15 @@ describe 'postgresql::client', :type => :class do
         :tag => 'postgresql',
       })
     end
+
+    it 'should have specified validate connexion' do
+      should contain_file('/opt/bin/my-validate-con.sh').with({
+        :ensure => 'file',
+        :owner  => 0,
+        :group  => 0,
+        :mode   => '0755'
+      })
+    end
   end
 
   describe 'with no parameters' do
