@@ -6,6 +6,10 @@ describe 'postgresql::server::tablespace', :type => :define do
       :osfamily => 'Debian',
       :operatingsystem => 'Debian',
       :operatingsystemrelease => '6.0',
+      :kernel => 'Linux',
+      :concat_basedir => tmpfilename('tablespace'),
+      :id => 'root',
+      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
     }
   end
 
@@ -19,5 +23,9 @@ describe 'postgresql::server::tablespace', :type => :define do
     }
   end
 
-  it { should contain_postgresql__server__tablespace('test') }
+  let :pre_condition do
+    "class {'postgresql::server':}"
+  end
+
+  it { is_expected.to contain_postgresql__server__tablespace('test') }
 end
