@@ -8,3 +8,7 @@ describe 'postgresql_escape', :type => :puppet_function do
   it { is_expected.to run.with_params('fo$$o').
     and_return('$ed$fo$$o$ed$') }
 end
+describe 'postgresql_escape', :type => :puppet_function do
+  it { is_expected.to run.with_params('foo$').
+    and_return('$a$foo$$a$') }
+end
